"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var url_1 = require("url");
var fs_1 = require("fs");
var chokidar_1 = require("chokidar");
var isRangeReq = require('../req/range').isRangeReq;
var r404_1 = require("../res/r404");
var r200_1 = require("../res/r200");
var r302_1 = require("../res/r302");
var output_1 = require("../../common/output");
function doFile(req, res, dir) {
    var filePath = getFilePath(dir, req.url);
    fs_1.exists(filePath, function (exists) {
        if (!exists) {
            r404_1.r404(res, {
                filePath: filePath
            });
            return;
        }
        if (fs_1.statSync(filePath).isDirectory()) {
            if (req.url) {
                var dirUrl = req.url.substr(-1) === '/' ? req.url : req.url + '/';
                r302_1.r302(res, dirUrl);
                return;
            }
        }
        isRangeReq(req);
        r200_1.res200(res, filePath);
    });
}
exports.doFile = doFile;
var watcher;
function watchFileChange(ws, dir) {
    if (watcher) {
        watcher.close();
    }
    watcher = chokidar_1.watch(dir, {
        ignored: /\.pcss$/
    })
        .on('change', function (p) {
        ws.send('reload', function () {
            output_1.log('detected file "' + p + '" changed, reloaded the page');
        });
    });
}
exports.watchFileChange = watchFileChange;
function getFilePath(dir, reqUrl) {
    if (reqUrl === void 0) { reqUrl = ''; }
    var parsedUrl = url_1.parse(reqUrl);
    var filePath = dir + parsedUrl.pathname;
    return filePath;
}
exports.getFilePath = getFilePath;
//# sourceMappingURL=file.js.map